@@ -3,7 +3,6 @@ from __future__ import annotations
 from typing import TYPE_CHECKING, Generic, Optional, TypeVar, cast
 
 from pls.config import constants
-from pls.data.utils import lookup
 from pls.globals import args
 from pls.models.base_node import BaseNode
 
@@ -37,10 +36,11 @@ class TreeMixin(Generic[T], BaseNode):
         return self.parent is not None
 
     @property
-    def is_visible_tree(self):
+    def is_visible(self) -> bool:
         """whether the node deserves to be rendered to the screen"""
 
-        return not self.is_sub or args.args.collapse <= 1
+        is_tree_visible = not self.is_sub or args.args.collapse <= 1
+        return is_tree_visible and super().is_visible
 
     @property
     def tree_prefix(self) -> str:
@@ -85,8 +85,8 @@ class TreeMixin(Generic[T], BaseNode):
         """
 
         return self.get_shape(
-            lookup(constants.constants, ["tree", "space_space"], ""),
-            lookup(constants.constants, ["tree", "pipe_space"], ""),
+            constants.constants.lookup(["tree", "space_space"], ""),
+            constants.constants.lookup(["tree", "pipe_space"], ""),
         )
 
     def _get_last_shape(self) -> str:
@@ -100,8 +100,8 @@ class TreeMixin(Generic[T], BaseNode):
         """
 
         return self.get_shape(
-            lookup(constants.constants, ["tree", "bend_dash"], ""),
-            lookup(constants.constants, ["tree", "tee_dash"], ""),
+            constants.constants.lookup(["tree", "bend_dash"], ""),
+            constants.constants.lookup(["tree", "tee_dash"], ""),
         )
 
     def set_sub_pre_shapes(self):
