@@ -58,12 +58,6 @@ class Node(
 
         return f"{self.name} @ {self.path}"
 
-    @property
-    def is_visible(self):
-        """whether the node deserves to be rendered to the screen"""
-
-        return self.is_visible_imp and self.is_visible_tree
-
     @cached_property
     def format_rules(self) -> tuple[list[str], list[str]]:
         """the list of formatting rules to apply to the icons and text respectively"""
